from __future__ import absolute_import
from __future__ import division
from __future__ import print_function

from .__version__ import __url__, __version__


if __name__ == '__main__':
    print('SteelConnection version:', __version__)
    print('Documentation available at', __url__)
